==> evolution-1.4.6.zip: evolution-1.4.6/assets/modules/store/lang/nederlands-utf8.php <==
<?php
/*List pack */
$_Lang['version'] = "Versie";
$_Lang['suthor'] = "auteur";
$_Lang['date'] = "Uitgebracht";
$_Lang['downloads'] = "Geupload";
$_Lang['install'] = "Installeer";
$_Lang['reinstall'] = "Herstellen";
$_Lang['update'] = "Updaten";
$_Lang['installed'] = "voltooid";
$_Lang['installed2'] = "Geinstalleerd";
$_Lang['exit'] = "Sluit";
$_Lang['alert_overwrite'] = "Installeren van deze add-on zal uw bestaande overschrijven. Verder gaan?";

/*Main*/
$_Lang['store_name'] = "Pakket Manager";
$_Lang['version_evailble'] = "Een nieuwe versie";
$_Lang['category'] = "Categorieën";

/*Login form*/
$_Lang['enter_in_own_repository'] = "Inloggen opslagplaats";
$_Lang['password'] = "Wachtwoord";
$_Lang['enter'] = "&nbsp;&nbsp;&nbsp;&nbsp;Inloggen&nbsp;&nbsp;&nbsp;&nbsp;";
$_Lang['email'] = "E-mail";
$_Lang['register'] = "&nbsp;&nbsp;&nbsp;Registreren&nbsp;&nbsp;&nbsp;";
$_Lang['own_repository'] = "Mijn opslagplaats";
$_Lang['login_errors'] = "Fout e-mailadres of wachtwoord";

/* & Tpl filters */
$_Lang['s1_1_reated_on'] = "Gemaakt";
$_Lang['s1_2_name'] = "Titel";
$_Lang['s1_3_position'] = "Positie";
$_Lang['s1_4_published'] = "Updaten";
$_Lang['s2_1_up'] = "Aflopend";
$_Lang['s2_2_down'] = "Oplopend";
$_Lang['search'] = "Zoeken binnen categorie:";

/* Installation by file-upload */
+$_Lang['install_file'] = "Installatie vanuit archief";
+$_Lang['choose_file_msg'] = "Selecteer bestand";
+$_Lang['install_file_btn'] = "Installeer";
+$_Lang['install_file_success'] = "Installatie voltooid";

/* faq */
$_Lang['faq'] = '
<li><a href="http://modx-store.com/faq/whatfor.html" target="_blank">Waarom heb je een opslagplaats nodig?</a></li>
<li><a href="http://modx-store.com/faq/howtoadd.html" target="_blank">Hoe voeg je een pakket toe aan de opslagplaats?</a></li>
<li><a href="http://modx-store.com/faq/howtocollect.html" target="_blank">Hoe maak je een pakket voor de opslagplaats?</a></li>';

?>

==> evolution-1.4.36.zip: evolution-1.4.36/assets/modules/store/lang/nederlands-utf8.php <==
<?php
/*List pack */
$_Lang['version'] = "Versie";
$_Lang['suthor'] = "auteur";
$_Lang['date'] = "Uitgebracht";
$_Lang['downloads'] = "Geupload";
$_Lang['install'] = "Installeer";
$_Lang['reinstall'] = "Herstellen";
$_Lang['update'] = "Updaten";
$_Lang['installed'] = "voltooid";
$_Lang['installed2'] = "Geinstalleerd";
$_Lang['exit'] = "Sluit";
$_Lang['alert_overwrite'] = "Installeren van deze add-on zal uw bestaande overschrijven. Verder gaan?";

/*Main*/
$_Lang['store_name'] = "Pakket Manager";
$_Lang['version_evailble'] = "Een nieuwe versie";
$_Lang['category'] = "Categorieën";

/*Login form*/
$_Lang['enter_in_own_repository'] = "Inloggen opslagplaats";
$_Lang['password'] = "Wachtwoord";
$_Lang['enter'] = "&nbsp;&nbsp;&nbsp;&nbsp;Inloggen&nbsp;&nbsp;&nbsp;&nbsp;";
$_Lang['email'] = "E-mail";
$_Lang['register'] = "&nbsp;&nbsp;&nbsp;Registreren&nbsp;&nbsp;&nbsp;";
$_Lang['own_repository'] = "Mijn opslagplaats";
$_Lang['login_errors'] = "Fout e-mailadres of wachtwoord";

/* & Tpl filters */
$_Lang['s1_1_reated_on'] = "Gemaakt";
$_Lang['s1_2_name'] = "Titel";
$_Lang['s1_3_position'] = "Positie";
$_Lang['s1_4_published'] = "Updaten";
$_Lang['s2_1_up'] = "Aflopend";
$_Lang['s2_2_down'] = "Oplopend";
$_Lang['search'] = "Zoeken binnen categorie:";

/* Installation by file-upload */
$_Lang['install_file'] = "Installatie vanuit archief";
$_Lang['choose_file_msg'] = "Selecteer bestand";
$_Lang['install_file_btn'] = "Installeer";
$_Lang['install_file_success'] = "Installatie voltooid";

/* faq */
$_Lang['faq'] = '
<li><a href="http://modx-store.com/faq/whatfor.html" target="_blank">Waarom heb je een opslagplaats nodig?</a></li>
<li><a href="http://modx-store.com/faq/howtoadd.html" target="_blank">Hoe voeg je een pakket toe aan de opslagplaats?</a></li>
<li><a href="http://modx-store.com/faq/howtocollect.html" target="_blank">Hoe maak je een pakket voor de opslagplaats?</a></li>';

?>
